import { Component, Input, OnInit } from '@angular/core';
import * as Chart from 'chart.js';

@Component({
  selector: 'app-chart',
  templateUrl: './chart.component.html',
  styleUrls: ['./chart.component.scss']
})
export class ChartComponent implements OnInit {

  @Input() current: number = 0;
  @Input() data: object[] = [];
  public chart: Chart | null = null;
  constructor() { }

  ngOnInit(): void {
    this.makeChart();
  }

  private makeChartData(): { labels: string[], data: number[] } {
    let labels: string[] = [], data: number[] = [];

    for (let i = this.data.length - 1; i >= 0; i--) {
      let action: any = this.data[i];
      labels.push(`${action['date']} - ${action['time']}`);
      let amount: number = data.length > 0 && data[data.length - 1] != null ? data[data.length - 1] : this.current;
      amount = (action['status'] == 'up') ? amount + action['amount'] : amount - action['amount'];
      data.push(amount);
    }

    return { labels, data };
  }

  private makeChart(): void {
    let result = this.makeChartData();
    let canvas: HTMLCanvasElement = <HTMLCanvasElement>document.getElementById('chart'),
      ctx: any = canvas.getContext('2d');
    this.chart = new Chart(ctx, {
      type: 'line',
      data: {
        labels: result.labels,
        datasets: [{
          data: result.data,
          backgroundColor:
            '#76ff03',
          borderColor:
            '#76ff03',
          borderWidth: 1
        }]
      },
      options: {
        responsive: true,
        legend: {
          display: false
        },
        scales: {
          xAxes: [{
            ticks: {
              display: false
            },
            gridLines: {
              display: false
            }
          }],
          yAxes: [{
            ticks: {
              display: false
            },
            gridLines: {
              display: false
            }
          }]
        }
      }
    })
  }
}
