export interface Option {
    title: string, // title that show
    description?: string,

    name: string, // object key title (like: version)
    placeholder?: string,
    hint?: string,
    value: any[],
    type: 'radio' | 'text' | 'icon' | 'password' | 'domain',
    ltr?: boolean
}

export interface App {
    type: 'database' | 'rayconnect'
    name: string,
    logo: string,
    options: Option[]
}

export const apps: App[] = [
    {
        type: 'database',
        name: 'MongoDB',
        logo: '/assets/images/apps/mongodb.png',
        options: [
            {
                title: 'نام اپ',
                description: 'پروژه یک نام خانوادگی هستش اما یک اپ نام اصلیش هستش پس یک اپ باید نام درستی داشته باشه.',
                name: 'name',
                placeholder: 'نام اپ',
                hint: 'نام اپ میتونه "دیتابیس کاربران" یا "دیتابیس کش" یا "دیتابیس اصلی" باشه',
                value: [],
                type: 'text',
                ltr: false
            },
            {
                title: 'نسخه اپ',
                description: 'بر اساس سازگاری پروژه خودتون نسخه ی اپ رو انتخاب کنید و یا از آخرین نسخه بهره ببرید.',
                name: 'version',
                value: ['4.4', '4.2', '4.0', '3.6'],
                type: 'radio'
            },
            {
                title: 'موقعیت اپ',
                description: 'اپ شما می تونه هر جایی در اینترنت باشه ولی زندگی ثابتش رو در یک کشور می تونه داشته باشه.',
                name: 'location',
                value: [
                    {
                        image: '/assets/images/countries/iran.png',
                        name: 'جمهوری اسلامی ایران'
                    },
                    {
                        image: '/assets/images/countries/germany.png',
                        name: 'آلمان'
                    }
                ],
                type: 'icon'
            },
            {
                title: 'نام کاربری اپ',
                description: 'برای این اپ باید یه نام کاربری برای خودتون انتخاب کنید.',
                name: 'username',
                placeholder: 'نام کاربری',
                value: [],
                type: 'text',
                ltr: true
            },
            {
                title: 'گذرواژه اپ',
                description: 'برای این اپ علاوه بر نام کاربری ، یک گذرواژه نیاز هستش.',
                name: 'password',
                placeholder: 'گذرواژه',
                hint: 'باید بیشتر از 8 کارکتر باشد',
                value: [],
                type: 'password',
                ltr: true,
            },
            {
                title: 'آدرس دامنه اپ',
                description: 'آدرس دامنه شما که کاربران با وارد کردن آن می توانند اپ شما را ببینند. دامنه می تواند یکی از زیر دامنه های رایکانکت باشد یا دامنه اختصاصی که با DNS به هم متصل می شوند.',
                name: 'domain',
                placeholder: 'آدرس دامنه',
                hint: 'sub-domain.rayconnect.ir',
                value: [],
                type: 'domain',
                ltr: true
            }
        ]
    }
];