import { Component, OnInit, Pipe, PipeTransform } from '@angular/core';
import { apps, App } from '../../../../database/apps';
import { categories, Category } from '../../../../database/categories';

@Component({
  selector: 'app-create',
  templateUrl: './create.component.html',
  styleUrls: ['./create.component.scss']
})
export class CreateComponent implements OnInit {

  public categories: Category[] = categories; // inital categories from local database file
  public apps: App[] = apps; // inital apps from local database file
  public config: object | undefined; // selected app config (app.options)
  public plan: string | undefined; // selected plan key
  public step: number = 1;
  public type: string = ''; // app type
  public app: App | undefined;
  constructor() { }

  ngOnInit(): void {
  }

  selectType(type: string) {
    this.type = type;
    this.step = 2;
  }

  selectApp(app: App) {
    this.app = app;
    this.step = 3;
  }

  /**
   * set new step
   * @param step current is step + 1 and user want jump to step
   */
  setStep(step: number) {
    this.step = step;
    if (step == 1) this.type = '';
    if (step <= 2) this.app = undefined;
    if (step <= 3) this.plan = undefined;
  }

  setAppConfig(config: any) {
    this.config = config;
    this.step = 4;
  }

  setPricePlan(key: any) {
    this.plan = key;
    this.step = 5;
  }
}



@Pipe({
  name: 'filter'
})

export class FilterPipe implements PipeTransform {
  transform(items: App[], type: string): any {
    if (!items || !type) return items;
    else return items.filter(item => item.type == type);
  }
}