import { Component, EventEmitter, OnInit, Output } from '@angular/core';
import { FormControl, Validators } from '@angular/forms';
import { MatSnackBar } from '@angular/material/snack-bar';
import { SDK } from '../../sdk/sdk.service';

let timeout: any; // for check en name;

@Component({
  selector: 'app-create-projects',
  templateUrl: './create-projects.component.html',
  styleUrls: ['./create-projects.component.scss']
})
export class CreateProjectsComponent implements OnInit {

  public step: number = 1;
  public steps: number = 3;
  public checking: number = 0; // checking id
  public useable: boolean = false; // this id got used
  public randomIds: string[] = []; // random id with id + random number (4 digits)
  /// Form
  public minLength: number = 5; // min id length
  public name: FormControl = new FormControl('', { validators: [Validators.required, Validators.minLength(this.minLength)] });
  public id: FormControl = new FormControl('', { validators: [Validators.required, Validators.minLength(this.minLength), Validators.pattern(/^[A-Za-z0-9]*$/)] });
  @Output() close: EventEmitter<void> = new EventEmitter<void>();
  @Output() project: EventEmitter<object> = new EventEmitter<object>();
  constructor(private snackbar: MatSnackBar, private sdk: SDK) { }

  ngOnInit(): void {
  }

  prev() {
    if (this.step == 2) {
      this.id.reset();
      this.checking = 0; // hide loading
      this.useable = false; // this id cannot use cause loading
      this.randomIds = []; // clear created random ids
    }
    this.step -= 1;
  }

  next() {
    // if user must enter project name and it was empty do noting
    if (this.step == 1 && this.name.invalid) return;
    this.step += 1;
  }

  closed() {
    this.close.emit();
    this.step = 1;
    this.name.reset();
    this.id.reset();
  }

  getErrorMessage(control: FormControl): string {
    let errors = control.errors;
    if (errors == null) return '';
    else if ('required' in errors) return 'این فیلد را خالی رها نکنید.';
    else if ('minlength' in errors) return `این فیلد نباید کمتر از ${this.minLength} کارکتر باشد.`;
    else if ('pattern' in errors) return 'شناسه باید حروف انگلیسی و اعداد بدون فاصله و نماد باشد.';
    else return 'این فیلد مشکل دارد.';
  }

  /**
   * 
   * @param event Keyup event
   */
  check(event: any): any {
    clearTimeout(timeout); // on keyup = clear timeout
    if (this.id.invalid) return; // if id was less then min length do noting at all
    if (this.useable == true && event['key'] == 'Enter') return this.submit(); // if user pressed Enter and checked id is true = id can use and it's unique
    this.checking = 0; // hide loading
    this.useable = false; // this id cannot use cause loading
    this.randomIds = []; // clear created random ids
    // do check id if id didn't check and keyup Enter, check force else take a while
    timeout = setTimeout(() => this.doCheck(), this.useable == false && event['key'] == 'Enter' ? 0 : 1000);
  }

  private async doCheck() {
    clearTimeout(timeout);
    try {
      this.checking = 1; // Start loading and checking id
      this.useable = false; // This id cannot use cause checking
      let result: number = await this.sdk.check(this.id.value);
      this.checking = 2; // End loading and checked id
      this.randomIds = [this.randomId(), this.randomId(), this.randomId()];
    } catch (error) {

    }
  }

  /**
   * Genrate random id from user id + 4 digits = new id
   */
  randomId(): string {
    let random: number = (Math.random() * 1000) + 1000;
    random = Math.floor(random);
    return this.id.value + random.toString();
  }

  /**
   * Create project
   */
  submit() {
    this.project.emit({ name: this.name, id: this.id });
    this.step = 3;
  }
}
