import { Injectable } from '@angular/core';
import { Rayconnect } from '../rayconnect/rayconnect.service';

interface Item {
  content: string, checked: boolean, timestamp: number,
}

@Injectable({
  providedIn: 'root'
})
export class Todo {

  public items: Item[] | null = null;
  public loading: boolean = false;
  constructor(private rayconnect: Rayconnect) { }

  async load(): Promise<Item[] | null> {
    try {
      this.loading = true;
      let data = await this.rayconnect.CloudStorage.getItem('todo');
      if (data) this.items = JSON.parse(data);
      else this.items = [];
      this.loading = false;
      return this.items;
    } catch (error) {
      this.loading = false;
      return [];
    }
  }

  async save(): Promise<boolean> {
    try {
      this.loading = true;
      await this.rayconnect.CloudStorage.setItem('todo', JSON.stringify(this.items));
      this.loading = false;
      return true;
    } catch (error) {
      this.loading = false;
      return false;
    }
  }

  async add(content: string): Promise<boolean> {
    this.items?.push({ content, checked: false, timestamp: Date.now() });
    return await this.save();
  }

  async remove(timestamp: number): Promise<boolean> {
    let index: any = this.items?.findIndex(item => item?.timestamp == timestamp);
    if (index >= 0) {
      this.items?.splice(index, 1);
      return await this.save();
    } else return false;
  }

  async check(timestamp: number, value: boolean): Promise<boolean> {
    let item = this.items?.find(item => item?.timestamp == timestamp);
    if (item) {
      item.checked = value;
      return this.save();
    } else return false;
  }

  async clear() {
    try {
      await this.rayconnect.CloudStorage.setItem('todo', null);
      return true;
    } catch (error) {
      return false;
    }
  }
}
